#[non_exhaustive]pub enum Value {
}Expand description
Engine-agnostic representation of a database value.
Drivers convert their native types into Value when reading rows and
in the opposite direction when binding parameters. Values that cannot be
expressed in one of the structured variants are preserved in
Value::Unknown as their textual rendering.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Null
Bool(bool)
Int(i64)
Float(f64)
String(String)
Bytes(Vec<u8>)
Date(NaiveDate)
Time(NaiveTime)
DateTime(NaiveDateTime)
Timestamp(DateTime<Utc>)
Uuid(Uuid)
Json(Value)
Unknown(String)
Implementations